# Widget Picture Generator
Developed by Sense Square

### Introduction
The Python library WidgetPictureGenerator has been designed to generate widget images quickly and easily. This library can be used to generate high-quality images of any type of widget, such as charts, maps, and leaderboards.

The WidgetPictureGenerator Python library supports a wide range of widgets, giving users the ability to select the desired type of widget and customize it to create an image that meets their needs. WidgetPictureGenerator is easy to use and comes with detailed documentation and numerous code examples to help users get started creating high-quality widget images.

### Based on Selenium
The WidgetPictureGenerator library uses the web automation framework Selenium to create widget images. Selenium is a widely used framework for web script automation and allows users to simulate user interaction with a web page.

### Selenium installation
Selenium requires a driver to interface with the chosen browser. Chrome, for example, requires chromedriver, which needs to be installed before the below examples can be run. Make sure it’s in your PATH, e. g., place it in /usr/bin or /usr/local/bin.

Failure to observe this step will give you an error selenium.common.exceptions.WebDriverException: Message: ‘chromedriver’ executable needs to be in PATH.

Chrome Drive Interface:	https://sites.google.com/chromium.org/driver/